/*
 * [SortKey.java]
 *
 * Summary: Information about One Sort Key field for generating a Comparator/Comparable.
 *
 * Copyright: (c) 2009-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2009-04-26 initial release
 */
package com.mindprod.comparatorcutter;

/**
 * Information about One Sort Key field for generating a Comparator/Comparable.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2009-04-26 initial release
 * @since 2009-04-26
 */
class SortKey
    {
    /**
     * tracks java type of sort key field
     */
    private final FieldType fieldType;

    /**
     * tracks name of sort key type
     */
    private final String fieldName;

    /**
     * true if we sort this field in descending order
     */
    private final boolean isFieldDescending;

    public SortKey( final FieldType fieldType, final boolean isFieldDescending, final String fieldName )
        {
        this.fieldType = fieldType;
        this.isFieldDescending = isFieldDescending;
        this.fieldName = fieldName;
        }

    public String getFieldName()
        {
        return fieldName;
        }

    public FieldType getFieldType()
        {
        return fieldType;
        }

    public boolean isFieldDescending()
        {
        return isFieldDescending;
        }
    }
